pub struct QueryStats {
pub trigrams_queried: u32,
pub posting_lists_decoded: u32,
pub candidate_files: u32,
pub files_verified: u32,
pub bytes_verified: u64,
pub total_matches: u32,
pub posting_cache_hits: u64,
pub posting_cache_misses: u64,
pub neg_cache_hits: u64,
pub neg_cache_misses: u64,
}Expand description
Performance counters collected during query execution.
Fields
trigrams_queried: u32Number of trigrams looked up in the trigram table.
posting_lists_decoded: u32Number of posting lists that were fully decoded from disk.
candidate_files: u32Number of candidate files after intersection and bloom filtering.
files_verified: u32Number of files whose content was verified against the regex.
bytes_verified: u64Total bytes of file content read during verification.
total_matches: u32Total number of matches produced.
posting_cache_hits: u64Posting list cache hits (decode avoided).
posting_cache_misses: u64Posting list cache misses (decode required).
neg_cache_hits: u64Negative cache hits (file verification skipped).
neg_cache_misses: u64Negative cache misses (file verification required).