run_daemon

Function run_daemon 

pub fn run_daemon(path: &Path) -> Result<()>
Run the daemon watching the given directory for changes and rebuilding the index.

Errors

Returns an error if the root cannot be canonicalized, the index cannot be built, or the file watcher fails.

Panics

Panics if the Ctrl-C handler cannot be set (which is extremely rare).