pub struct IdleTracker { /* private fields */ }Expand description
Tracks elapsed time since the last query and the last filesystem change
to determine the current DaemonState.
Implementations
Sourceimpl IdleTracker
impl IdleTracker
Sourcepub fn record_query(&mut self)
pub fn record_query(&mut self)
Mark that a search query was just received.
Sourcepub fn record_change(&mut self)
pub fn record_change(&mut self)
Mark that a filesystem change was just processed.
Sourcepub fn state(&self) -> DaemonState
pub fn state(&self) -> DaemonState
Return the current daemon state based on elapsed inactivity.