pub struct Planner;Expand description
Stateless query planner that decomposes user input into a QueryPlan.
Implementations
Sourceimpl Planner
impl Planner
Sourcepub fn plan(pattern: &str, is_regex: bool) -> QueryPlan
pub fn plan(pattern: &str, is_regex: bool) -> QueryPlan
Plan a literal or regex query with default options (non-unicode,
case-sensitive). See plan_with_options
for full control.
Sourcepub fn plan_with_pool(
pattern: &str,
options: QueryOptions,
pool: &RegexPool,
) -> QueryPlan
pub fn plan_with_pool( pattern: &str, options: QueryOptions, pool: &RegexPool, ) -> QueryPlan
Plan a query using a regex pool to avoid redundant compilation.
Identical to plan_with_options but
sources compiled regexes from pool when available.
Sourcepub fn plan_with_options(pattern: &str, options: QueryOptions) -> QueryPlan
pub fn plan_with_options(pattern: &str, options: QueryOptions) -> QueryPlan
Plan a query with full options.
Panics
Panics if Regex::new("") fails (which should never happen since an empty
pattern is always valid).