pub struct StringPool { /* private fields */ }Expand description
Path string pool with prefix deduplication.
Stores common directory prefixes and stores only the suffix for each path.
Implementations
Sourceimpl StringPool
impl StringPool
Sourcepub fn add_path(&mut self, path: &Path)
pub fn add_path(&mut self, path: &Path)
Add a path to the pool. During indexing, we just collect unique paths.
Real prefix deduplication happens during serialization or via pre-added prefixes.
Sourcepub fn set_prefixes(&mut self, prefixes: Vec<String>)
pub fn set_prefixes(&mut self, prefixes: Vec<String>)
Set the prefixes to be used for deduplication.