pub struct Watcher { /* private fields */ }Expand description
A file-system watcher that detects changes in a directory tree and batches them into debounced event batches.
Implementations
Sourceimpl Watcher
impl Watcher
Sourcepub fn new(root: &Path) -> Self
pub fn new(root: &Path) -> Self
Create a new watcher for the given root directory.
The watcher is not started yet; call Watcher::start to begin
receiving events.
Sourcepub fn start(&mut self) -> Result<Receiver<Vec<PathBuf>>>
pub fn start(&mut self) -> Result<Receiver<Vec<PathBuf>>>
Start watching the file system for changes.
Errors
Returns an error if the filesystem watcher cannot be created.
Sourcepub const fn is_running(&self) -> bool
pub const fn is_running(&self) -> bool
Returns true while the underlying notify watcher is active.