QueryOptions

Struct QueryOptions 

pub struct QueryOptions {
    pub count_only: bool,
    pub files_only: bool,
    pub max_results: usize,
    pub type_filter: Vec<String>,
    pub context_lines: usize,
    pub decompress: bool,
    pub threads: usize,
    pub multiline: bool,
    pub archive: bool,
    pub binary: bool,
}
Tunable knobs that control query execution behaviour.

Fields

count_only: bool

Only report match counts (not line content).

files_only: bool

Only list file paths containing matches.

max_results: usize

Maximum number of results to return (0 = unlimited).

type_filter: Vec<String>

File extensions to restrict the search to.

context_lines: usize

Number of context lines to show before and after each match.

decompress: bool

Transparently decompress archives (e.g. .gz) when scanning.

threads: usize

Number of Rayon threads to use for parallel work.

multiline: bool

Dot-matches-newline mode for regex matching.

archive: bool

Search inside archive files (zip, tar.gz).

binary: bool

Search binary files as if they were text.