pub struct PostingList {
pub entries: Vec<PostingEntry>,
}Expand description
A collection of per-file posting entries for a single trigram.
Fields
entries: Vec<PostingEntry>Ordered list of files that contain this trigram, with their hit offsets.
Implementations
Sourceimpl PostingList
impl PostingList
Sourcepub const ZSTD_COMPRESSION_LEVEL: i32 = 3
pub const ZSTD_COMPRESSION_LEVEL: i32 = 3
ZSTD compression level used for posting list and CDX block encoding.